@@ -10,11 +10,8 @@
 #ifndef __CDRDOCUMENT_H__
 #define __CDRDOCUMENT_H__
 
-#include <libwpd/libwpd.h>
-#include <libwpg/libwpg.h>
-#include "CDRStringVector.h"
-
-class WPXInputStream;
+#include <librevenge/librevenge.h>
+#include "libcdr_api.h"
 
 namespace libcdr
 {
@@ -22,11 +19,9 @@ class CDRDocument
 {
 public:
 
-  static bool isSupported(WPXInputStream *input);
+  static CDRAPI bool isSupported(librevenge::RVNGInputStream *input);
 
-  static bool parse(WPXInputStream *input, libwpg::WPGPaintInterface *painter);
-
-  static bool generateSVG(WPXInputStream *input, CDRStringVector &output);
+  static CDRAPI bool parse(librevenge::RVNGInputStream *input, librevenge::RVNGDrawingInterface *painter);
 };
 
 } // namespace libcdr
