@@ -12,8 +12,6 @@
 
 #include "CDRDocument.h"
 #include "CMXDocument.h"
-#include <libwpd/libwpd.h>
-#include <libwpg/libwpg.h>
 
 #endif
 /* vim:set shiftwidth=2 softtabstop=2 expandtab: */
