@@ -7,20 +7,25 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#include <math.h>
-#include <string.h>
 #include "CDRCollector.h"
+
+#include <math.h>
+#include <stack>
+#include <string.h>
+#include <lcms2.h>
+#include "CDRColorProfiles.h"
 #include "libcdr_utils.h"
 
 libcdr::CDRParserState::CDRParserState()
   : m_bmps(), m_patterns(), m_vects(), m_pages(), m_documentPalette(), m_texts(),
-    m_colorTransformCMYK2RGB(0), m_colorTransformLab2RGB(0), m_colorTransformRGB2RGB(0)
+    m_styles(), m_fillStyles(), m_lineStyles(),
+    m_colorTransformCMYK2RGB(nullptr), m_colorTransformLab2RGB(nullptr), m_colorTransformRGB2RGB(nullptr)
 {
   cmsHPROFILE tmpRGBProfile = cmsCreate_sRGBProfile();
   m_colorTransformRGB2RGB = cmsCreateTransform(tmpRGBProfile, TYPE_RGB_8, tmpRGBProfile, TYPE_RGB_8, INTENT_PERCEPTUAL, 0);
   cmsHPROFILE tmpCMYKProfile = cmsOpenProfileFromMem(CMYK_icc, sizeof(CMYK_icc)/sizeof(CMYK_icc[0]));
   m_colorTransformCMYK2RGB = cmsCreateTransform(tmpCMYKProfile, TYPE_CMYK_DBL, tmpRGBProfile, TYPE_RGB_8, INTENT_PERCEPTUAL, 0);
-  cmsHPROFILE tmpLabProfile = cmsCreateLab4Profile(0);
+  cmsHPROFILE tmpLabProfile = cmsCreateLab4Profile(nullptr);
   m_colorTransformLab2RGB = cmsCreateTransform(tmpLabProfile, TYPE_Lab_DBL, tmpRGBProfile, TYPE_RGB_8, INTENT_PERCEPTUAL, 0);
   cmsCloseProfile(tmpLabProfile);
   cmsCloseProfile(tmpCMYKProfile);
@@ -69,7 +74,7 @@ void libcdr::CDRParserState::setColorTransform(const std::vector<unsigned char>
   cmsCloseProfile(tmpRGBProfile);
 }
 
-void libcdr::CDRParserState::setColorTransform(WPXInputStream *input)
+void libcdr::CDRParserState::setColorTransform(librevenge::RVNGInputStream *input)
 {
   if (!input)
     return;
@@ -303,7 +308,7 @@ unsigned libcdr::CDRParserState::_getRGBColor(const CDRColor &color)
       0x00, 0x46, 0x73, 0x91, 0xa2, 0xad, 0x2a, 0x3d, 0x69, 0x7d, 0x85, 0x8f, 0xa3,
     };
 
-    unsigned short pantoneIndex = (unsigned short)(((int)col1 << 8) | (int)col0);
+    auto pantoneIndex = (unsigned short)(((int)col1 << 8) | (int)col0);
     double pantoneSaturation = (double)(((unsigned short)col3 << 8) | (unsigned short)col2) / 100.0;
     typedef struct
     {
@@ -320,9 +325,9 @@ unsigned libcdr::CDRParserState::_getRGBColor(const CDRColor &color)
       pureColor.g = WaldoColorType0_G[pantoneIndex];
       pureColor.b = WaldoColorType0_B[pantoneIndex];
     }
-    unsigned tmpRed = (unsigned)cdr_round(255.0*(1-pantoneSaturation) + (double)pureColor.r*pantoneSaturation);
-    unsigned tmpGreen = (unsigned)cdr_round(255.0*(1-pantoneSaturation) + (double)pureColor.g*pantoneSaturation);
-    unsigned tmpBlue = (unsigned)cdr_round(255.0*(1-pantoneSaturation) + (double)pureColor.b*pantoneSaturation);
+    auto tmpRed = (unsigned)cdr_round(255.0*(1-pantoneSaturation) + (double)pureColor.r*pantoneSaturation);
+    auto tmpGreen = (unsigned)cdr_round(255.0*(1-pantoneSaturation) + (double)pureColor.g*pantoneSaturation);
+    auto tmpBlue = (unsigned)cdr_round(255.0*(1-pantoneSaturation) + (double)pureColor.b*pantoneSaturation);
     red = (tmpRed < 255 ? (unsigned char)tmpRed : 255);
     green = (tmpGreen < 255 ? (unsigned char)tmpGreen : 255);
     blue = (tmpBlue < 255 ? (unsigned char)tmpBlue : 255);
@@ -388,7 +393,7 @@ unsigned libcdr::CDRParserState::_getRGBColor(const CDRColor &color)
   // HSB
   case 0x06:
   {
-    unsigned short hue = (unsigned short)(((int)col1<<8) | col0);
+    auto hue = (unsigned short)(((int)col1<<8) | col0);
     double saturation = (double)col2/255.0;
     double brightness = (double)col3/255.0;
 
@@ -423,7 +428,7 @@ unsigned libcdr::CDRParserState::_getRGBColor(const CDRColor &color)
   // HLS
   case 0x07:
   {
-    unsigned short hue = (unsigned short)(((int)col1<<8) | col0);
+    auto hue = (unsigned short)(((int)col1<<8) | col0);
     double lightness = (double)col2/255.0;
     double saturation = (double)col3/255.0;
 
@@ -469,6 +474,14 @@ unsigned libcdr::CDRParserState::_getRGBColor(const CDRColor &color)
     }
     break;
   }
+  // BW
+  case 0x08:
+  {
+    red = col0 ? 0 : 0xff;
+    green = col0 ? 0 : 0xff;
+    blue = col0 ? 0 : 0xff;
+    break;
+  }
   // Grayscale
   case 0x09:
   {
@@ -480,9 +493,9 @@ unsigned libcdr::CDRParserState::_getRGBColor(const CDRColor &color)
   // YIQ255
   case 0x0b:
   {
-    double y = (double)col0;
-    double i = (double)col1;
-    double q = (double)col2;
+    auto y = (double)col0;
+    auto i = (double)col1;
+    auto q = (double)col2;
 
     y -= 100.0;
     if (y < 0.0)
@@ -560,11 +573,38 @@ unsigned libcdr::CDRParserState::_getRGBColor(const CDRColor &color)
   return (unsigned)((red << 16) | (green << 8) | blue);
 }
 
-WPXString libcdr::CDRParserState::getRGBColorString(const libcdr::CDRColor &color)
+librevenge::RVNGString libcdr::CDRParserState::getRGBColorString(const libcdr::CDRColor &color)
 {
-  WPXString tempString;
+  librevenge::RVNGString tempString;
   tempString.sprintf("#%.6x", _getRGBColor(color));
   return tempString;
 }
 
+void libcdr::CDRParserState::getRecursedStyle(CDRStyle &style, unsigned styleId)
+{
+  std::map<unsigned, CDRStyle>::const_iterator iter = m_styles.find(styleId);
+  if (iter == m_styles.end())
+    return;
+
+  std::stack<CDRStyle> styleStack;
+  styleStack.push(iter->second);
+  if (iter->second.m_parentId)
+  {
+    std::map<unsigned, CDRStyle>::const_iterator iter2 = m_styles.find(iter->second.m_parentId);
+    while (iter2 != m_styles.end())
+    {
+      styleStack.push(iter2->second);
+      if (iter2->second.m_parentId)
+        iter2 = m_styles.find(iter2->second.m_parentId);
+      else
+        iter2 = m_styles.end();
+    }
+  }
+  while (!styleStack.empty())
+  {
+    style.overrideStyle(styleStack.top());
+    styleStack.pop();
+  }
+}
+
 /* vim:set shiftwidth=2 softtabstop=2 expandtab: */
