@@ -7,19 +7,21 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
+#include "CDRPath.h"
+
 #include <math.h>
 #include <map>
-#include "CDRPath.h"
-#include "CDRTypes.h"
 
-#ifndef M_PI
-#define M_PI 3.14159265358979323846
-#endif
+#include "CDRTransforms.h"
+#include "libcdr_utils.h"
 
 #ifndef DEBUG_SPLINES
 #define DEBUG_SPLINES 0
 #endif
 
+namespace libcdr
+{
+
 namespace
 {
 
@@ -220,20 +222,17 @@ static void getCubicBezierBBox(double x0, double y0, double x1, double y1, doubl
 
 } // anonymous namespace
 
-namespace libcdr
-{
-
 class CDRMoveToElement : public CDRPathElement
 {
 public:
   CDRMoveToElement(double x, double y)
     : m_x(x),
       m_y(y) {}
-  ~CDRMoveToElement() {}
-  void writeOut(WPXPropertyListVector &vec) const;
-  void transform(const CDRTransforms &trafos);
-  void transform(const CDRTransform &trafo);
-  CDRPathElement *clone();
+  ~CDRMoveToElement() override {}
+  void writeOut(librevenge::RVNGPropertyListVector &vec) const override;
+  void transform(const CDRTransforms &trafos) override;
+  void transform(const CDRTransform &trafo) override;
+  std::unique_ptr<CDRPathElement> clone() override;
 private:
   double m_x;
   double m_y;
@@ -245,11 +244,11 @@ public:
   CDRLineToElement(double x, double y)
     : m_x(x),
       m_y(y) {}
-  ~CDRLineToElement() {}
-  void writeOut(WPXPropertyListVector &vec) const;
-  void transform(const CDRTransforms &trafos);
-  void transform(const CDRTransform &trafo);
-  CDRPathElement *clone();
+  ~CDRLineToElement() override {}
+  void writeOut(librevenge::RVNGPropertyListVector &vec) const override;
+  void transform(const CDRTransforms &trafos) override;
+  void transform(const CDRTransform &trafo) override;
+  std::unique_ptr<CDRPathElement> clone() override;
 private:
   double m_x;
   double m_y;
@@ -265,11 +264,11 @@ public:
       m_y2(y2),
       m_x(x),
       m_y(y) {}
-  ~CDRCubicBezierToElement() {}
-  void writeOut(WPXPropertyListVector &vec) const;
-  void transform(const CDRTransforms &trafos);
-  void transform(const CDRTransform &trafo);
-  CDRPathElement *clone();
+  ~CDRCubicBezierToElement() override {}
+  void writeOut(librevenge::RVNGPropertyListVector &vec) const override;
+  void transform(const CDRTransforms &trafos) override;
+  void transform(const CDRTransform &trafo) override;
+  std::unique_ptr<CDRPathElement> clone() override;
 private:
   double m_x1;
   double m_y1;
@@ -287,11 +286,11 @@ public:
       m_y1(y1),
       m_x(x),
       m_y(y) {}
-  ~CDRQuadraticBezierToElement() {}
-  void writeOut(WPXPropertyListVector &vec) const;
-  void transform(const CDRTransforms &trafos);
-  void transform(const CDRTransform &trafo);
-  CDRPathElement *clone();
+  ~CDRQuadraticBezierToElement() override {}
+  void writeOut(librevenge::RVNGPropertyListVector &vec) const override;
+  void transform(const CDRTransforms &trafos) override;
+  void transform(const CDRTransform &trafo) override;
+  std::unique_ptr<CDRPathElement> clone() override;
 private:
   double m_x1;
   double m_y1;
@@ -304,11 +303,11 @@ class CDRSplineToElement : public CDRPathElement
 public:
   CDRSplineToElement(const std::vector<std::pair<double, double> > &points)
     : m_points(points) {}
-  ~CDRSplineToElement() {}
-  void writeOut(WPXPropertyListVector &vec) const;
-  void transform(const CDRTransforms &trafos);
-  void transform(const CDRTransform &trafo);
-  CDRPathElement *clone();
+  ~CDRSplineToElement() override {}
+  void writeOut(librevenge::RVNGPropertyListVector &vec) const override;
+  void transform(const CDRTransforms &trafos) override;
+  void transform(const CDRTransform &trafo) override;
+  std::unique_ptr<CDRPathElement> clone() override;
 private:
   std::vector<std::pair<double, double> > m_points;
   unsigned knot(unsigned i) const;
@@ -325,11 +324,11 @@ public:
       m_sweep(sweep),
       m_x(x),
       m_y(y) {}
-  ~CDRArcToElement() {}
-  void writeOut(WPXPropertyListVector &vec) const;
-  void transform(const CDRTransforms &trafos);
-  void transform(const CDRTransform &trafo);
-  CDRPathElement *clone();
+  ~CDRArcToElement() override {}
+  void writeOut(librevenge::RVNGPropertyListVector &vec) const override;
+  void transform(const CDRTransforms &trafos) override;
+  void transform(const CDRTransform &trafo) override;
+  std::unique_ptr<CDRPathElement> clone() override;
 private:
   double m_rx;
   double m_ry;
@@ -344,68 +343,65 @@ class CDRClosePathElement : public CDRPathElement
 {
 public:
   CDRClosePathElement() {}
-  ~CDRClosePathElement() {}
-  void writeOut(WPXPropertyListVector &vec) const;
-  void transform(const CDRTransforms &trafos);
-  void transform(const CDRTransform &trafo);
-  CDRPathElement *clone();
+  ~CDRClosePathElement() override {}
+  void writeOut(librevenge::RVNGPropertyListVector &vec) const override;
+  void transform(const CDRTransforms &trafos) override;
+  void transform(const CDRTransform &trafo) override;
+  std::unique_ptr<CDRPathElement> clone() override;
 };
 
-} // namespace libcdr
-
-
-void libcdr::CDRMoveToElement::writeOut(WPXPropertyListVector &vec) const
+void CDRMoveToElement::writeOut(librevenge::RVNGPropertyListVector &vec) const
 {
-  WPXPropertyList node;
-  node.insert("libwpg:path-action", "M");
+  librevenge::RVNGPropertyList node;
+  node.insert("librevenge:path-action", "M");
   node.insert("svg:x", m_x);
   node.insert("svg:y", m_y);
   vec.append(node);
 }
 
-void libcdr::CDRMoveToElement::transform(const CDRTransforms &trafos)
+void CDRMoveToElement::transform(const CDRTransforms &trafos)
 {
   trafos.applyToPoint(m_x,m_y);
 }
 
-void libcdr::CDRMoveToElement::transform(const CDRTransform &trafo)
+void CDRMoveToElement::transform(const CDRTransform &trafo)
 {
   trafo.applyToPoint(m_x,m_y);
 }
 
-libcdr::CDRPathElement *libcdr::CDRMoveToElement::clone()
+std::unique_ptr<CDRPathElement> CDRMoveToElement::clone()
 {
-  return new CDRMoveToElement(m_x, m_y);
+  return make_unique<CDRMoveToElement>(m_x, m_y);
 }
 
-void libcdr::CDRLineToElement::writeOut(WPXPropertyListVector &vec) const
+void CDRLineToElement::writeOut(librevenge::RVNGPropertyListVector &vec) const
 {
-  WPXPropertyList node;
-  node.insert("libwpg:path-action", "L");
+  librevenge::RVNGPropertyList node;
+  node.insert("librevenge:path-action", "L");
   node.insert("svg:x", m_x);
   node.insert("svg:y", m_y);
   vec.append(node);
 }
 
-void libcdr::CDRLineToElement::transform(const CDRTransforms &trafos)
+void CDRLineToElement::transform(const CDRTransforms &trafos)
 {
   trafos.applyToPoint(m_x,m_y);
 }
 
-void libcdr::CDRLineToElement::transform(const CDRTransform &trafo)
+void CDRLineToElement::transform(const CDRTransform &trafo)
 {
   trafo.applyToPoint(m_x,m_y);
 }
 
-libcdr::CDRPathElement *libcdr::CDRLineToElement::clone()
+std::unique_ptr<CDRPathElement> CDRLineToElement::clone()
 {
-  return new CDRLineToElement(m_x, m_y);
+  return make_unique<CDRLineToElement>(m_x, m_y);
 }
 
-void libcdr::CDRCubicBezierToElement::writeOut(WPXPropertyListVector &vec) const
+void CDRCubicBezierToElement::writeOut(librevenge::RVNGPropertyListVector &vec) const
 {
-  WPXPropertyList node;
-  node.insert("libwpg:path-action", "C");
+  librevenge::RVNGPropertyList node;
+  node.insert("librevenge:path-action", "C");
   node.insert("svg:x1", m_x1);
   node.insert("svg:y1", m_y1);
   node.insert("svg:x2", m_x2);
@@ -415,29 +411,29 @@ void libcdr::CDRCubicBezierToElement::writeOut(WPXPropertyListVector &vec) const
   vec.append(node);
 }
 
-void libcdr::CDRCubicBezierToElement::transform(const CDRTransforms &trafos)
+void CDRCubicBezierToElement::transform(const CDRTransforms &trafos)
 {
   trafos.applyToPoint(m_x1,m_y1);
   trafos.applyToPoint(m_x2,m_y2);
   trafos.applyToPoint(m_x,m_y);
 }
 
-void libcdr::CDRCubicBezierToElement::transform(const CDRTransform &trafo)
+void CDRCubicBezierToElement::transform(const CDRTransform &trafo)
 {
   trafo.applyToPoint(m_x1,m_y1);
   trafo.applyToPoint(m_x2,m_y2);
   trafo.applyToPoint(m_x,m_y);
 }
 
-libcdr::CDRPathElement *libcdr::CDRCubicBezierToElement::clone()
+std::unique_ptr<CDRPathElement> CDRCubicBezierToElement::clone()
 {
-  return new CDRCubicBezierToElement(m_x1, m_y1, m_x2, m_y2, m_x, m_y);
+  return make_unique<CDRCubicBezierToElement>(m_x1, m_y1, m_x2, m_y2, m_x, m_y);
 }
 
-void libcdr::CDRQuadraticBezierToElement::writeOut(WPXPropertyListVector &vec) const
+void CDRQuadraticBezierToElement::writeOut(librevenge::RVNGPropertyListVector &vec) const
 {
-  WPXPropertyList node;
-  node.insert("libwpg:path-action", "Q");
+  librevenge::RVNGPropertyList node;
+  node.insert("librevenge:path-action", "Q");
   node.insert("svg:x1", m_x1);
   node.insert("svg:y1", m_y1);
   node.insert("svg:x", m_x);
@@ -445,26 +441,26 @@ void libcdr::CDRQuadraticBezierToElement::writeOut(WPXPropertyListVector &vec) c
   vec.append(node);
 }
 
-void libcdr::CDRQuadraticBezierToElement::transform(const CDRTransforms &trafos)
+void CDRQuadraticBezierToElement::transform(const CDRTransforms &trafos)
 {
   trafos.applyToPoint(m_x1,m_y1);
   trafos.applyToPoint(m_x,m_y);
 }
 
-void libcdr::CDRQuadraticBezierToElement::transform(const CDRTransform &trafo)
+void CDRQuadraticBezierToElement::transform(const CDRTransform &trafo)
 {
   trafo.applyToPoint(m_x1,m_y1);
   trafo.applyToPoint(m_x,m_y);
 }
 
-libcdr::CDRPathElement *libcdr::CDRQuadraticBezierToElement::clone()
+std::unique_ptr<CDRPathElement> CDRQuadraticBezierToElement::clone()
 {
-  return new CDRQuadraticBezierToElement(m_x1, m_y1, m_x, m_y);
+  return make_unique<CDRQuadraticBezierToElement>(m_x1, m_y1, m_x, m_y);
 }
 
 #define CDR_SPLINE_DEGREE 3
 
-unsigned libcdr::CDRSplineToElement::knot(unsigned i) const
+unsigned CDRSplineToElement::knot(unsigned i) const
 {
   /* Emulates knot vector of an uniform B-Spline of degree 3 */
   if (i < CDR_SPLINE_DEGREE)
@@ -474,28 +470,28 @@ unsigned libcdr::CDRSplineToElement::knot(unsigned i) const
   return i - CDR_SPLINE_DEGREE;
 }
 
-void libcdr::CDRSplineToElement::writeOut(WPXPropertyListVector &vec) const
+void CDRSplineToElement::writeOut(librevenge::RVNGPropertyListVector &vec) const
 {
-  WPXPropertyList node;
+  librevenge::RVNGPropertyList node;
 
 #if DEBUG_SPLINES
   /* Code for visual debugging of the spline decomposition */
 
-  node.insert("libwpg:path-action", "M");
+  node.insert("librevenge:path-action", "M");
   node.insert("svg:x", m_points[0].first);
   node.insert("svg:y", m_points[0].second);
   vec.append(node);
 
   for (unsigned j = 0; j < m_points.size(); ++j)
   {
-    node.insert("libwpg:path-action", "L");
+    node.insert("librevenge:path-action", "L");
     node.insert("svg:x", m_points[j].first);
     node.insert("svg:y", m_points[j].second);
     vec.append(node);
   }
 #endif
 
-  node.insert("libwpg:path-action", "M");
+  node.insert("librevenge:path-action", "M");
   node.insert("svg:x", m_points[0].first);
   node.insert("svg:y", m_points[0].second);
   vec.append(node);
@@ -520,7 +516,7 @@ void libcdr::CDRSplineToElement::writeOut(WPXPropertyListVector &vec) const
     unsigned mult = b - i + 1;
     if (mult < CDR_SPLINE_DEGREE)
     {
-      double numer = (double)(knot(b) - knot(a));
+      auto numer = (double)(knot(b) - knot(a));
       unsigned j = CDR_SPLINE_DEGREE;
       std::map<unsigned, double> alphas;
       for (; j >mult; j--)
@@ -546,7 +542,7 @@ void libcdr::CDRSplineToElement::writeOut(WPXPropertyListVector &vec) const
     // Pass the segment to the path
 
     node.clear();
-    node.insert("libwpg:path-action", "C");
+    node.insert("librevenge:path-action", "C");
     node.insert("svg:x1", Qw[1].first);
     node.insert("svg:y1", Qw[1].second);
     node.insert("svg:x2", Qw[2].first);
@@ -571,170 +567,165 @@ void libcdr::CDRSplineToElement::writeOut(WPXPropertyListVector &vec) const
   }
 }
 
-void libcdr::CDRSplineToElement::transform(const CDRTransforms &trafos)
+void CDRSplineToElement::transform(const CDRTransforms &trafos)
 {
-  for (std::vector<std::pair<double, double> >::iterator iter = m_points.begin();
-       iter != m_points.end(); ++iter)
-    trafos.applyToPoint(iter->first, iter->second);
+  for (auto &point : m_points)
+    trafos.applyToPoint(point.first, point.second);
 }
 
-void libcdr::CDRSplineToElement::transform(const CDRTransform &trafo)
+void CDRSplineToElement::transform(const CDRTransform &trafo)
 {
-  for (std::vector<std::pair<double, double> >::iterator iter = m_points.begin();
-       iter != m_points.end(); ++iter)
-    trafo.applyToPoint(iter->first, iter->second);
+  for (auto &point : m_points)
+    trafo.applyToPoint(point.first, point.second);
 }
 
-libcdr::CDRPathElement *libcdr::CDRSplineToElement::clone()
+std::unique_ptr<CDRPathElement> CDRSplineToElement::clone()
 {
-  return new CDRSplineToElement(m_points);
+  return libcdr::make_unique<CDRSplineToElement>(m_points);
 }
 
-void libcdr::CDRArcToElement::writeOut(WPXPropertyListVector &vec) const
+void CDRArcToElement::writeOut(librevenge::RVNGPropertyListVector &vec) const
 {
-  WPXPropertyList node;
-  node.insert("libwpg:path-action", "A");
+  librevenge::RVNGPropertyList node;
+  node.insert("librevenge:path-action", "A");
   node.insert("svg:rx", m_rx);
   node.insert("svg:ry", m_ry);
-  node.insert("libwpg:rotate", m_rotation * 180 / M_PI, WPX_GENERIC);
-  node.insert("libwpg:large-arc", m_largeArc);
-  node.insert("libwpg:sweep", m_sweep);
+  node.insert("librevenge:rotate", m_rotation * 180 / M_PI, librevenge::RVNG_GENERIC);
+  node.insert("librevenge:large-arc", m_largeArc);
+  node.insert("librevenge:sweep", m_sweep);
   node.insert("svg:x", m_x);
   node.insert("svg:y", m_y);
   vec.append(node);
 }
 
-void libcdr::CDRArcToElement::transform(const CDRTransforms &trafos)
+void CDRArcToElement::transform(const CDRTransforms &trafos)
 {
   trafos.applyToArc(m_rx, m_ry, m_rotation, m_sweep, m_x, m_y);
 }
 
-void libcdr::CDRArcToElement::transform(const CDRTransform &trafo)
+void CDRArcToElement::transform(const CDRTransform &trafo)
 {
   trafo.applyToArc(m_rx, m_ry, m_rotation, m_sweep, m_x, m_y);
 }
 
-libcdr::CDRPathElement *libcdr::CDRArcToElement::clone()
+std::unique_ptr<CDRPathElement> CDRArcToElement::clone()
 {
-  return new CDRArcToElement(m_rx, m_ry, m_rotation, m_largeArc, m_sweep, m_x, m_y);
+  return make_unique<CDRArcToElement>(m_rx, m_ry, m_rotation, m_largeArc, m_sweep, m_x, m_y);
 }
 
-void libcdr::CDRClosePathElement::transform(const CDRTransforms &)
+void CDRClosePathElement::transform(const CDRTransforms &)
 {
 }
 
-void libcdr::CDRClosePathElement::transform(const CDRTransform &)
+void CDRClosePathElement::transform(const CDRTransform &)
 {
 }
 
-libcdr::CDRPathElement *libcdr::CDRClosePathElement::clone()
+std::unique_ptr<CDRPathElement> CDRClosePathElement::clone()
 {
-  return new CDRClosePathElement();
+  return make_unique<CDRClosePathElement>();
 }
 
-void libcdr::CDRClosePathElement::writeOut(WPXPropertyListVector &vec) const
+void CDRClosePathElement::writeOut(librevenge::RVNGPropertyListVector &vec) const
 {
-  WPXPropertyList node;
-  node.insert("libwpg:path-action", "Z");
+  librevenge::RVNGPropertyList node;
+  node.insert("librevenge:path-action", "Z");
   vec.append(node);
 }
 
-void libcdr::CDRPath::appendMoveTo(double x, double y)
+void CDRPath::appendMoveTo(double x, double y)
 {
-  m_elements.push_back(new libcdr::CDRMoveToElement(x, y));
+  m_elements.push_back(make_unique<CDRMoveToElement>(x, y));
 }
 
-void libcdr::CDRPath::appendLineTo(double x, double y)
+void CDRPath::appendLineTo(double x, double y)
 {
-  m_elements.push_back(new libcdr::CDRLineToElement(x, y));
+  m_elements.push_back(make_unique<CDRLineToElement>(x, y));
 }
 
-void libcdr::CDRPath::appendCubicBezierTo(double x1, double y1, double x2, double y2, double x, double y)
+void CDRPath::appendCubicBezierTo(double x1, double y1, double x2, double y2, double x, double y)
 {
-  m_elements.push_back(new libcdr::CDRCubicBezierToElement(x1, y1, x2, y2, x, y));
+  m_elements.push_back(make_unique<CDRCubicBezierToElement>(x1, y1, x2, y2, x, y));
 }
 
-void libcdr::CDRPath::appendQuadraticBezierTo(double x1, double y1, double x, double y)
+void CDRPath::appendQuadraticBezierTo(double x1, double y1, double x, double y)
 {
-  m_elements.push_back(new libcdr::CDRQuadraticBezierToElement(x1, y1, x, y));
+  m_elements.push_back(make_unique<CDRQuadraticBezierToElement>(x1, y1, x, y));
 }
 
-void libcdr::CDRPath::appendArcTo(double rx, double ry, double rotation, bool longAngle, bool sweep, double x, double y)
+void CDRPath::appendArcTo(double rx, double ry, double rotation, bool longAngle, bool sweep, double x, double y)
 {
-  m_elements.push_back(new libcdr::CDRArcToElement(rx, ry, rotation, longAngle, sweep, x, y));
+  m_elements.push_back(make_unique<CDRArcToElement>(rx, ry, rotation, longAngle, sweep, x, y));
 }
 
-void libcdr::CDRPath::appendSplineTo(std::vector<std::pair<double, double> > &points)
+void CDRPath::appendSplineTo(const std::vector<std::pair<double, double> > &points)
 {
-  m_elements.push_back(new libcdr::CDRSplineToElement(points));
+  m_elements.push_back(libcdr::make_unique<CDRSplineToElement>(points));
 }
 
-void libcdr::CDRPath::appendClosePath()
+void CDRPath::appendClosePath()
 {
-  m_elements.push_back(new libcdr::CDRClosePathElement());
+  m_elements.push_back(make_unique<CDRClosePathElement>());
   m_isClosed = true;
 }
 
-libcdr::CDRPath::CDRPath(const libcdr::CDRPath &path) : m_elements(), m_isClosed(false)
+CDRPath::CDRPath(const CDRPath &path) : m_elements(), m_isClosed(false)
 {
-  for (std::vector<CDRPathElement *>::const_iterator iter = path.m_elements.begin(); iter != path.m_elements.end(); ++iter)
-    m_elements.push_back((*iter)->clone());
+  appendPath(path);
   m_isClosed = path.isClosed();
 }
 
-libcdr::CDRPath &libcdr::CDRPath::operator=(const libcdr::CDRPath &path)
+CDRPath &CDRPath::operator=(const CDRPath &path)
 {
   // Check for self-assignment
   if (this == &path)
     return *this;
   clear();
-  for (std::vector<CDRPathElement *>::const_iterator iter = path.m_elements.begin(); iter != path.m_elements.end(); ++iter)
-    m_elements.push_back((*iter)->clone());
+  appendPath(path);
   m_isClosed = path.isClosed();
   return *this;
 }
 
 
-libcdr::CDRPath::~CDRPath()
+CDRPath::~CDRPath()
 {
-  clear();
 }
 
-void libcdr::CDRPath::appendPath(const CDRPath &path)
+void CDRPath::appendPath(const CDRPath &path)
 {
-  for (std::vector<CDRPathElement *>::const_iterator iter = path.m_elements.begin(); iter != path.m_elements.end(); ++iter)
-    m_elements.push_back((*iter)->clone());
+  for (const auto &element : path.m_elements)
+    m_elements.push_back(element->clone());
 }
 
-void libcdr::CDRPath::writeOut(WPXPropertyListVector &vec) const
+void CDRPath::writeOut(librevenge::RVNGPropertyListVector &vec) const
 {
   bool wasZ = true;
-  for (std::vector<CDRPathElement *>::const_iterator iter = m_elements.begin(); iter != m_elements.end(); ++iter)
+  for (const auto &element : m_elements)
   {
-    if (dynamic_cast<CDRClosePathElement *>(*iter))
+    if (dynamic_cast<CDRClosePathElement *>(element.get()))
     {
       if (!wasZ)
       {
-        (*iter)->writeOut(vec);
+        element->writeOut(vec);
         wasZ = true;
       }
     }
     else
     {
-      (*iter)->writeOut(vec);
+      element->writeOut(vec);
       wasZ = false;
     }
   }
 }
 
-void libcdr::CDRPath::writeOut(WPXString &path, WPXString &viewBox, double &width) const
+void CDRPath::writeOut(librevenge::RVNGString &path, librevenge::RVNGString &viewBox, double &width) const
 {
-  WPXPropertyListVector vec;
+  librevenge::RVNGPropertyListVector vec;
   writeOut(vec);
   if (vec.count() == 0)
     return;
   // This must be a mistake and we do not want to crash lower
-  if (vec[0]["libwpg:path-action"]->getStr() == "Z")
+  if (vec[0]["librevenge:path-action"]->getStr() == "Z")
     return;
 
   // try to find the bounding box
@@ -744,7 +735,7 @@ void libcdr::CDRPath::writeOut(WPXString &path, WPXString &viewBox, double &widt
   double lastX = 0.0;
   double lastY = 0.0;
 
-  for (unsigned k = 0; k < vec.count(); ++k)
+  for (unsigned long k = 0; k < vec.count(); ++k)
   {
     if (!vec[k]["svg:x"] || !vec[k]["svg:y"])
       continue;
@@ -765,7 +756,7 @@ void libcdr::CDRPath::writeOut(WPXString &path, WPXString &viewBox, double &widt
 
     double xmin, xmax, ymin, ymax;
 
-    if (vec[k]["libwpg:path-action"]->getStr() == "C")
+    if (vec[k]["librevenge:path-action"]->getStr() == "C")
     {
       getCubicBezierBBox(lastX, lastY, vec[k]["svg:x1"]->getDouble(), vec[k]["svg:y1"]->getDouble(),
                          vec[k]["svg:x2"]->getDouble(), vec[k]["svg:y2"]->getDouble(),
@@ -776,7 +767,7 @@ void libcdr::CDRPath::writeOut(WPXString &path, WPXString &viewBox, double &widt
       qx = (qx < xmax ? xmax : qx);
       qy = (qy < ymax ? ymax : qy);
     }
-    if (vec[k]["libwpg:path-action"]->getStr() == "Q")
+    if (vec[k]["librevenge:path-action"]->getStr() == "Q")
     {
       getQuadraticBezierBBox(lastX, lastY, vec[k]["svg:x1"]->getDouble(), vec[k]["svg:y1"]->getDouble(),
                              vec[k]["svg:x"]->getDouble(), vec[k]["svg:y"]->getDouble(), xmin, ymin, xmax, ymax);
@@ -786,12 +777,12 @@ void libcdr::CDRPath::writeOut(WPXString &path, WPXString &viewBox, double &widt
       qx = (qx < xmax ? xmax : qx);
       qy = (qy < ymax ? ymax : qy);
     }
-    if (vec[k]["libwpg:path-action"]->getStr() == "A")
+    if (vec[k]["librevenge:path-action"]->getStr() == "A")
     {
       getEllipticalArcBBox(lastX, lastY, vec[k]["svg:rx"]->getDouble(), vec[k]["svg:ry"]->getDouble(),
-                           vec[k]["libwpg:rotate"] ? vec[k]["libwpg:rotate"]->getDouble() : 0.0,
-                           vec[k]["libwpg:large-arc"] ? vec[k]["libwpg:large-arc"]->getInt() : 1,
-                           vec[k]["libwpg:sweep"] ? vec[k]["libwpg:sweep"]->getInt() : 1,
+                           vec[k]["librevenge:rotate"] ? vec[k]["librevenge:rotate"]->getDouble() : 0.0,
+                           vec[k]["librevenge:large-arc"] ? vec[k]["librevenge:large-arc"]->getInt() : 1,
+                           vec[k]["librevenge:sweep"] ? vec[k]["librevenge:sweep"]->getInt() : 1,
                            vec[k]["svg:x"]->getDouble(), vec[k]["svg:y"]->getDouble(), xmin, ymin, xmax, ymax);
 
       px = (px > xmin ? xmin : px);
@@ -805,89 +796,88 @@ void libcdr::CDRPath::writeOut(WPXString &path, WPXString &viewBox, double &widt
 
 
   width = qy - py;
-  viewBox.sprintf("%i %i %i %i", 0, 0, (unsigned)(2540*(qx - px)), (unsigned)(2540*(qy - py)));
+  viewBox.sprintf("%i %i %i %i", 0, 0, (int)(2540*(qx - px)), (int)(2540*(qy - py)));
 
-  for (unsigned i = 0; i < vec.count(); ++i)
+  for (unsigned long i = 0; i < vec.count(); ++i)
   {
-    WPXString sElement;
-    if (vec[i]["libwpg:path-action"]->getStr() == "M")
+    librevenge::RVNGString sElement;
+    if (vec[i]["librevenge:path-action"]->getStr() == "M")
     {
       // 2540 is 2.54*1000, 2.54 in = 1 inch
-      sElement.sprintf("M%i %i", (unsigned)((vec[i]["svg:x"]->getDouble()-px)*2540),
-                       (unsigned)((vec[i]["svg:y"]->getDouble()-py)*2540));
+      sElement.sprintf("M%i %i", (int)((vec[i]["svg:x"]->getDouble()-px)*2540),
+                       (int)((vec[i]["svg:y"]->getDouble()-py)*2540));
       path.append(sElement);
     }
-    else if (vec[i]["libwpg:path-action"]->getStr() == "L")
+    else if (vec[i]["librevenge:path-action"]->getStr() == "L")
     {
-      sElement.sprintf("L%i %i", (unsigned)((vec[i]["svg:x"]->getDouble()-px)*2540),
-                       (unsigned)((vec[i]["svg:y"]->getDouble()-py)*2540));
+      sElement.sprintf("L%i %i", (int)((vec[i]["svg:x"]->getDouble()-px)*2540),
+                       (int)((vec[i]["svg:y"]->getDouble()-py)*2540));
       path.append(sElement);
     }
-    else if (vec[i]["libwpg:path-action"]->getStr() == "C")
+    else if (vec[i]["librevenge:path-action"]->getStr() == "C")
     {
-      sElement.sprintf("C%i %i %i %i %i %i", (unsigned)((vec[i]["svg:x1"]->getDouble()-px)*2540),
-                       (unsigned)((vec[i]["svg:y1"]->getDouble()-py)*2540), (unsigned)((vec[i]["svg:x2"]->getDouble()-px)*2540),
-                       (unsigned)((vec[i]["svg:y2"]->getDouble()-py)*2540), (unsigned)((vec[i]["svg:x"]->getDouble()-px)*2540),
-                       (unsigned)((vec[i]["svg:y"]->getDouble()-py)*2540));
+      sElement.sprintf("C%i %i %i %i %i %i", (int)((vec[i]["svg:x1"]->getDouble()-px)*2540),
+                       (int)((vec[i]["svg:y1"]->getDouble()-py)*2540), (int)((vec[i]["svg:x2"]->getDouble()-px)*2540),
+                       (int)((vec[i]["svg:y2"]->getDouble()-py)*2540), (int)((vec[i]["svg:x"]->getDouble()-px)*2540),
+                       (int)((vec[i]["svg:y"]->getDouble()-py)*2540));
       path.append(sElement);
     }
-    else if (vec[i]["libwpg:path-action"]->getStr() == "Q")
+    else if (vec[i]["librevenge:path-action"]->getStr() == "Q")
     {
-      sElement.sprintf("Q%i %i %i %i", (unsigned)((vec[i]["svg:x1"]->getDouble()-px)*2540),
-                       (unsigned)((vec[i]["svg:y1"]->getDouble()-py)*2540), (unsigned)((vec[i]["svg:x"]->getDouble()-px)*2540),
-                       (unsigned)((vec[i]["svg:y"]->getDouble()-py)*2540));
+      sElement.sprintf("Q%i %i %i %i", (int)((vec[i]["svg:x1"]->getDouble()-px)*2540),
+                       (int)((vec[i]["svg:y1"]->getDouble()-py)*2540), (int)((vec[i]["svg:x"]->getDouble()-px)*2540),
+                       (int)((vec[i]["svg:y"]->getDouble()-py)*2540));
       path.append(sElement);
     }
-    else if (vec[i]["libwpg:path-action"]->getStr() == "A")
+    else if (vec[i]["librevenge:path-action"]->getStr() == "A")
     {
-      sElement.sprintf("A%i %i %i %i %i %i %i", (unsigned)((vec[i]["svg:rx"]->getDouble())*2540),
-                       (unsigned)((vec[i]["svg:ry"]->getDouble())*2540), (vec[i]["libwpg:rotate"] ? vec[i]["libwpg:rotate"]->getInt() : 0),
-                       (vec[i]["libwpg:large-arc"] ? vec[i]["libwpg:large-arc"]->getInt() : 1),
-                       (vec[i]["libwpg:sweep"] ? vec[i]["libwpg:sweep"]->getInt() : 1),
-                       (unsigned)((vec[i]["svg:x"]->getDouble()-px)*2540), (unsigned)((vec[i]["svg:y"]->getDouble()-py)*2540));
+      sElement.sprintf("A%i %i %i %i %i %i %i", (int)((vec[i]["svg:rx"]->getDouble())*2540),
+                       (int)((vec[i]["svg:ry"]->getDouble())*2540), (vec[i]["librevenge:rotate"] ? vec[i]["librevenge:rotate"]->getInt() : 0),
+                       (vec[i]["librevenge:large-arc"] ? vec[i]["librevenge:large-arc"]->getInt() : 1),
+                       (vec[i]["librevenge:sweep"] ? vec[i]["librevenge:sweep"]->getInt() : 1),
+                       (int)((vec[i]["svg:x"]->getDouble()-px)*2540), (int)((vec[i]["svg:y"]->getDouble()-py)*2540));
       path.append(sElement);
     }
-    else if (vec[i]["libwpg:path-action"]->getStr() == "Z")
+    else if (vec[i]["librevenge:path-action"]->getStr() == "Z")
     {
       path.append(" Z");
     }
   }
 }
 
-void libcdr::CDRPath::transform(const CDRTransforms &trafos)
+void CDRPath::transform(const CDRTransforms &trafos)
 {
-  for (std::vector<CDRPathElement *>::iterator iter = m_elements.begin(); iter != m_elements.end(); ++iter)
-    (*iter)->transform(trafos);
+  for (auto &element : m_elements)
+    element->transform(trafos);
 }
 
-void libcdr::CDRPath::transform(const CDRTransform &trafo)
+void CDRPath::transform(const CDRTransform &trafo)
 {
-  for (std::vector<CDRPathElement *>::iterator iter = m_elements.begin(); iter != m_elements.end(); ++iter)
-    (*iter)->transform(trafo);
+  for (auto &element : m_elements)
+    element->transform(trafo);
 }
 
-libcdr::CDRPathElement *libcdr::CDRPath::clone()
+std::unique_ptr<CDRPathElement> CDRPath::clone()
 {
-  return new CDRPath(*this);
+  return make_unique<CDRPath>(*this);
 }
 
-void libcdr::CDRPath::clear()
+void CDRPath::clear()
 {
-  for (std::vector<CDRPathElement *>::iterator iter = m_elements.begin(); iter != m_elements.end(); ++iter)
-    if (*iter)
-      delete(*iter);
   m_elements.clear();
   m_isClosed = false;
 }
 
-bool libcdr::CDRPath::empty() const
+bool CDRPath::empty() const
 {
   return m_elements.empty();
 }
 
-bool libcdr::CDRPath::isClosed() const
+bool CDRPath::isClosed() const
 {
   return m_isClosed;
 }
 
+}
+
 /* vim:set shiftwidth=2 softtabstop=2 expandtab: */
