@@ -7,10 +7,13 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#include <string.h>
-
 #include "libcdr_utils.h"
 
+#include <cassert>
+#include <cstdarg>
+#include <cstdio>
+#include <string.h>
+
 #include <unicode/ucsdet.h>
 #include <unicode/ucnv.h>
 #include <unicode/utypes.h>
@@ -22,6 +25,7 @@
 
 namespace
 {
+
 static unsigned short getEncodingFromICUName(const char *name)
 {
   // ANSI
@@ -98,7 +102,7 @@ static unsigned short getEncoding(const unsigned char *buffer, unsigned bufferLe
   if (!buffer)
     return 0;
   UErrorCode status = U_ZERO_ERROR;
-  UCharsetDetector *csd = 0;
+  UCharsetDetector *csd = nullptr;
   try
   {
     csd = ucsdet_open(&status);
@@ -139,7 +143,7 @@ static unsigned short getEncoding(const unsigned char *buffer, unsigned bufferLe
   }
 }
 
-static void _appendUCS4(WPXString &text, UChar32 ucs4Character)
+static void _appendUCS4(librevenge::RVNGString &text, UChar32 ucs4Character)
 {
   // Convert carriage returns to new line characters
   // Writerperfect/LibreOffice will replace them by <text:line-break>
@@ -156,9 +160,9 @@ static void _appendUCS4(WPXString &text, UChar32 ucs4Character)
 
 } // anonymous namespace
 
-uint8_t libcdr::readU8(WPXInputStream *input, bool /* bigEndian */)
+uint8_t libcdr::readU8(librevenge::RVNGInputStream *input, bool /* bigEndian */)
 {
-  if (!input || input->atEOS())
+  if (!input || input->isEnd())
   {
     CDR_DEBUG_MSG(("Throwing EndOfStreamException\n"));
     throw EndOfStreamException();
@@ -172,9 +176,9 @@ uint8_t libcdr::readU8(WPXInputStream *input, bool /* bigEndian */)
   throw EndOfStreamException();
 }
 
-uint16_t libcdr::readU16(WPXInputStream *input, bool bigEndian)
+uint16_t libcdr::readU16(librevenge::RVNGInputStream *input, bool bigEndian)
 {
-  if (!input || input->atEOS())
+  if (!input || input->isEnd())
   {
     CDR_DEBUG_MSG(("Throwing EndOfStreamException\n"));
     throw EndOfStreamException();
@@ -192,14 +196,14 @@ uint16_t libcdr::readU16(WPXInputStream *input, bool bigEndian)
   throw EndOfStreamException();
 }
 
-int16_t libcdr::readS16(WPXInputStream *input, bool bigEndian)
+int16_t libcdr::readS16(librevenge::RVNGInputStream *input, bool bigEndian)
 {
   return (int16_t)readU16(input, bigEndian);
 }
 
-uint32_t libcdr::readU32(WPXInputStream *input, bool bigEndian)
+uint32_t libcdr::readU32(librevenge::RVNGInputStream *input, bool bigEndian)
 {
-  if (!input || input->atEOS())
+  if (!input || input->isEnd())
   {
     CDR_DEBUG_MSG(("Throwing EndOfStreamException\n"));
     throw EndOfStreamException();
@@ -217,14 +221,14 @@ uint32_t libcdr::readU32(WPXInputStream *input, bool bigEndian)
   throw EndOfStreamException();
 }
 
-int32_t libcdr::readS32(WPXInputStream *input, bool bigEndian)
+int32_t libcdr::readS32(librevenge::RVNGInputStream *input, bool bigEndian)
 {
   return (int32_t)readU32(input, bigEndian);
 }
 
-uint64_t libcdr::readU64(WPXInputStream *input, bool bigEndian)
+uint64_t libcdr::readU64(librevenge::RVNGInputStream *input, bool bigEndian)
 {
-  if (!input || input->atEOS())
+  if (!input || input->isEnd())
   {
     CDR_DEBUG_MSG(("Throwing EndOfStreamException\n"));
     throw EndOfStreamException();
@@ -242,7 +246,7 @@ uint64_t libcdr::readU64(WPXInputStream *input, bool bigEndian)
   throw EndOfStreamException();
 }
 
-double libcdr::readDouble(WPXInputStream *input, bool bigEndian)
+double libcdr::readDouble(librevenge::RVNGInputStream *input, bool bigEndian)
 {
   union
   {
@@ -255,26 +259,62 @@ double libcdr::readDouble(WPXInputStream *input, bool bigEndian)
   return tmpUnion.d;
 }
 
-double libcdr::readFixedPoint(WPXInputStream *input, bool bigEndian)
+double libcdr::readFixedPoint(librevenge::RVNGInputStream *input, bool bigEndian)
 {
   unsigned fixedPointNumber = readU32(input, bigEndian);
-  short fixedPointNumberIntegerPart = (short)((fixedPointNumber & 0xFFFF0000) >> 16);
-  double fixedPointNumberFractionalPart = (double)((double)(fixedPointNumber & 0x0000FFFF)/(double)0xFFFF);
+  auto fixedPointNumberIntegerPart = (short)((fixedPointNumber & 0xFFFF0000) >> 16);
+  auto fixedPointNumberFractionalPart = (double)((double)(fixedPointNumber & 0x0000FFFF)/(double)0xFFFF);
   return ((double)fixedPointNumberIntegerPart + fixedPointNumberFractionalPart);
 }
 
+unsigned long libcdr::getLength(librevenge::RVNGInputStream *const input)
+{
+  if (!input)
+    throw EndOfStreamException();
+
+  const long orig = input->tell();
+  long end = 0;
+
+  if (input->seek(0, librevenge::RVNG_SEEK_END) == 0)
+  {
+    end = input->tell();
+  }
+  else
+  {
+    // RVNG_SEEK_END does not work. Use the harder way.
+    if (input->seek(0, librevenge::RVNG_SEEK_SET) != 0)
+      throw EndOfStreamException();
+    while (!input->isEnd())
+    {
+      readU8(input);
+      ++end;
+    }
+  }
+  assert(end >= 0);
+
+  if (input->seek(orig, librevenge::RVNG_SEEK_SET) != 0)
+    throw EndOfStreamException();
+
+  return static_cast<unsigned long>(end);
+}
+
+unsigned long libcdr::getRemainingLength(librevenge::RVNGInputStream *const input)
+{
+  return getLength(input) - static_cast<unsigned long>(input->tell());
+}
+
 int libcdr::cdr_round(double d)
 {
   return (d>0) ? int(d+0.5) : int(d-0.5);
 }
 
-void libcdr::writeU16(WPXBinaryData &buffer, const int value)
+void libcdr::writeU16(librevenge::RVNGBinaryData &buffer, const int value)
 {
   buffer.append((unsigned char)(value & 0xFF));
   buffer.append((unsigned char)((value >> 8) & 0xFF));
 }
 
-void libcdr::writeU32(WPXBinaryData &buffer, const int value)
+void libcdr::writeU32(librevenge::RVNGBinaryData &buffer, const int value)
 {
   buffer.append((unsigned char)(value & 0xFF));
   buffer.append((unsigned char)((value >> 8) & 0xFF));
@@ -282,12 +322,7 @@ void libcdr::writeU32(WPXBinaryData &buffer, const int value)
   buffer.append((unsigned char)((value >> 24) & 0xFF));
 }
 
-void libcdr::writeU8(WPXBinaryData &buffer, const int value)
-{
-  buffer.append((unsigned char)(value & 0xFF));
-}
-
-void libcdr::appendCharacters(WPXString &text, std::vector<unsigned char> characters, unsigned short charset)
+void libcdr::appendCharacters(librevenge::RVNGString &text, std::vector<unsigned char> characters, unsigned short charset)
 {
   if (characters.empty())
     return;
@@ -342,7 +377,7 @@ void libcdr::appendCharacters(WPXString &text, std::vector<unsigned char> charac
   else
   {
     UErrorCode status = U_ZERO_ERROR;
-    UConverter *conv = NULL;
+    UConverter *conv = nullptr;
     switch (charset)
     {
     case 0x80: // SHIFTJIS
@@ -390,7 +425,7 @@ void libcdr::appendCharacters(WPXString &text, std::vector<unsigned char> charac
     }
     if (U_SUCCESS(status) && conv)
     {
-      const char *src = (const char *)&characters[0];
+      const auto *src = (const char *)&characters[0];
       const char *srcLimit = (const char *)src + characters.size();
       while (src < srcLimit)
       {
@@ -404,7 +439,7 @@ void libcdr::appendCharacters(WPXString &text, std::vector<unsigned char> charac
   }
 }
 
-void libcdr::appendCharacters(WPXString &text, std::vector<unsigned char> characters)
+void libcdr::appendCharacters(librevenge::RVNGString &text, std::vector<unsigned char> characters)
 {
   if (characters.empty())
     return;
@@ -414,7 +449,7 @@ void libcdr::appendCharacters(WPXString &text, std::vector<unsigned char> charac
 
   if (U_SUCCESS(status) && conv)
   {
-    const char *src = (const char *)&characters[0];
+    const auto *src = (const char *)&characters[0];
     const char *srcLimit = (const char *)src + characters.size();
     while (src < srcLimit)
     {
@@ -428,6 +463,15 @@ void libcdr::appendCharacters(WPXString &text, std::vector<unsigned char> charac
 }
 
 #ifdef DEBUG
+
+void libcdr::debugPrint(const char *const format, ...)
+{
+  va_list args;
+  va_start(args, format);
+  std::vfprintf(stderr, format, args);
+  va_end(args);
+}
+
 const char *libcdr::toFourCC(unsigned value, bool bigEndian)
 {
   static char sValue[5] = { 0, 0, 0, 0, 0 };
